@@ -1,5 +1,3 @@
-# -*- encoding: utf-8 -*-
-#
 # Copyright 2016–2021 Julien Danjou
 # Copyright 2016 Joshua Harlow
 # Copyright 2013-2014 Ray Holder
@@ -16,49 +14,52 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import abc
+import typing
 
-import six
+if typing.TYPE_CHECKING:
+    import threading
+
+    from tenacity import RetryCallState
 
 
-@six.add_metaclass(abc.ABCMeta)
-class stop_base(object):
+class stop_base(abc.ABC):
     """Abstract base class for stop strategies."""
 
     @abc.abstractmethod
-    def __call__(self, retry_state):
+    def __call__(self, retry_state: "RetryCallState") -> bool:
         pass
 
-    def __and__(self, other):
+    def __and__(self, other: "stop_base") -> "stop_all":
         return stop_all(self, other)
 
-    def __or__(self, other):
+    def __or__(self, other: "stop_base") -> "stop_any":
         return stop_any(self, other)
 
 
 class stop_any(stop_base):
     """Stop if any of the stop condition is valid."""
 
-    def __init__(self, *stops):
+    def __init__(self, *stops: stop_base) -> None:
         self.stops = stops
 
-    def __call__(self, retry_state):
+    def __call__(self, retry_state: "RetryCallState") -> bool:
         return any(x(retry_state) for x in self.stops)
 
 
 class stop_all(stop_base):
     """Stop if all the stop conditions are valid."""
 
-    def __init__(self, *stops):
+    def __init__(self, *stops: stop_base) -> None:
         self.stops = stops
 
-    def __call__(self, retry_state):
+    def __call__(self, retry_state: "RetryCallState") -> bool:
         return all(x(retry_state) for x in self.stops)
 
 
 class _stop_never(stop_base):
     """Never stop."""
 
-    def __call__(self, retry_state):
+    def __call__(self, retry_state: "RetryCallState") -> bool:
         return False
 
 
@@ -68,28 +69,28 @@ stop_never = _stop_never()
 class stop_when_event_set(stop_base):
     """Stop when the given event is set."""
 
-    def __init__(self, event):
+    def __init__(self, event: "threading.Event") -> None:
         self.event = event
 
-    def __call__(self, retry_state):
+    def __call__(self, retry_state: "RetryCallState") -> bool:
         return self.event.is_set()
 
 
 class stop_after_attempt(stop_base):
     """Stop when the previous attempt >= max_attempt."""
 
-    def __init__(self, max_attempt_number):
+    def __init__(self, max_attempt_number: int) -> None:
         self.max_attempt_number = max_attempt_number
 
-    def __call__(self, retry_state):
+    def __call__(self, retry_state: "RetryCallState") -> bool:
         return retry_state.attempt_number >= self.max_attempt_number
 
 
 class stop_after_delay(stop_base):
     """Stop when the time from the first attempt >= limit."""
 
-    def __init__(self, max_delay):
+    def __init__(self, max_delay: float) -> None:
         self.max_delay = max_delay
 
-    def __call__(self, retry_state):
+    def __call__(self, retry_state: "RetryCallState") -> bool:
         return retry_state.seconds_since_start >= self.max_delay
